﻿using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Windows;
using Infragistics.Windows.DataPresenter;

namespace GridTesting
{
    ///=================================================================================================
    /// <summary>   Add field layout behavior.  </summary>
    ///
    /// <remarks>   Cdo, 8/30/2011. </remarks>
    ///=================================================================================================

    public class AddFieldLayoutBehavior
    {
        ///-------------------------------------------------------------------------------------------------
        /// <summary>   Registers the attached. </summary>
        ///
        /// <remarks>   Collin O' Connor, 8/18/2011. </remarks>
        ///-------------------------------------------------------------------------------------------------

        public static readonly DependencyProperty FieldLayoutsProperty = DependencyProperty.RegisterAttached(
        @"FieldLayouts",
        typeof(ObservableCollection<FieldLayout>),
        typeof(AddFieldLayoutBehavior),
        new PropertyMetadata(null, OnFieldLayoutsUpdated)
        );

        ///=================================================================================================
        /// <summary>   Sets a multi field items. </summary>
        ///
        /// <remarks>   Cdo, 8/30/2011. </remarks>
        ///
        /// <param name="dependencyObject"> The dependency object. </param>
        /// <param name="fieldLayouts">     The field layouts. </param>
        ///=================================================================================================

        public static void SetFieldLayouts(DependencyObject dependencyObject, ObservableCollection<FieldLayout> fieldLayouts)
        {
            dependencyObject.SetValue(FieldLayoutsProperty, fieldLayouts);
        }

        ///=================================================================================================
        /// <summary>   Gets a multi field items. </summary>
        ///
        /// <remarks>   Cdo, 8/30/2011. </remarks>
        ///
        /// <param name="dependencyObject"> The dependency object. </param>
        ///
        /// <returns>   The multi field items. </returns>
        ///=================================================================================================

        public static ObservableCollection<FieldLayout> GetFieldLayouts(DependencyObject dependencyObject)
        {
            return dependencyObject.GetValue(FieldLayoutsProperty) as ObservableCollection<FieldLayout>;
        }

        ///=================================================================================================
        /// <summary>   Executes the field layouts updated action. </summary>
        ///
        /// <remarks>   Cdo, 8/30/2011. </remarks>
        ///=================================================================================================

        private static void OnFieldLayoutsUpdated(DependencyObject d, DependencyPropertyChangedEventArgs e)
        {
            var target = d as XamDataGrid;
            var layouts = e.NewValue as IList<FieldLayout>;
            if ((target == null) ||
                 (layouts == null))
            {
                return;
            }

            /*if (LogicalTreeHelper.GetParent(target) != null)
                return;*/

            target.FieldLayouts.Clear();

            foreach (var layout in layouts)
            {
                target.FieldLayouts.Add(layout);
            }
        }
    }
}
